@@ -36,10 +36,18 @@ IgnoreOpt = Annotated[list[str], Option(
     '--ignore', '-i', show_default=False, help=''
     'A path to be ignored relative to the target path. Can be used multiple times.'
 )]
+OnlyConfigOpt = Annotated[bool, Option(
+    '--only-config', '-o', show_default=False, help=''
+    'Whether to bump the project version number only in the .devtools configuration file, '
+    'skipping any project descriptor files. False by default.'
+)]
 
 
 @app.command(name="track", epilog="Example: devtools version track --name app")
-def cmd_track(name: NameOpt, target: TargetOpt = '.', ignore: IgnoreOpt = None):
+def cmd_track(name: NameOpt,
+              target: TargetOpt = '.',
+              ignore: IgnoreOpt = None,
+              only_config: OnlyConfigOpt = False) -> None:
     """
     Tracks changes inside the specified target path using file hashing.
     Defaults to the .devtools config directory if called without 'target' option.
@@ -70,15 +78,16 @@ def cmd_track(name: NameOpt, target: TargetOpt = '.', ignore: IgnoreOpt = None):
             index = i
 
     if track_path.is_file():
-        track_hash = hash_file(track_path)
+        track_hash = digest_file(track_path)
     else:
-        track_hash = hash_directory(track_path, ignore)
+        track_hash = digest_directory(track_path, ignore)
 
+    config.only_config = only_config
     comp = TrackedComponent(
-        name=name,
+        hash=track_hash,
         target=target,
         ignore=ignore,
-        hash=track_hash
+        name=name
     )
 
     if index is None:
@@ -174,14 +183,15 @@ def cmd_bump(
         console.print("[bold]Did not bump the project version.\n")
         raise SystemExit()
 
-    write_descriptor_file_version(new_version)
+    if not config.only_config:
+        write_descriptor_file_version(new_version)
 
     for comp in config.components:
         track_path = config_file.parent / comp.target
         if track_path.is_file():
-            track_hash = hash_file(track_path)
+            track_hash = digest_file(track_path)
         else:
-            track_hash = hash_directory(track_path, comp.ignore)
+            track_hash = digest_directory(track_path, comp.ignore)
         comp.hash = track_hash
 
     config.app_version = new_version
@@ -208,6 +218,7 @@ def cmd_echo(name: NameOpt = '', ghenv: GitHubEnvOpt = '', ghout: GitHubOutOpt =
     config: VersionConfig = read_local_config_file(VersionConfig)
     var_map = [(ghenv, GitHubFile.ENV), (ghout, GitHubFile.OUT)]
     if not name:
+        validate_version(config.app_version)
         console.print(config.app_version)
         [
             write_to_github_file(key, config.app_version, file)
@@ -216,6 +227,7 @@ def cmd_echo(name: NameOpt = '', ghenv: GitHubEnvOpt = '', ghout: GitHubOutOpt =
         return
     else:
         for entry in config.components:
+            validate_digest(entry.hash)
             if entry.name == name:
                 console.print(entry.hash)
                 [
@@ -243,9 +255,9 @@ def cmd_regen():
     for comp in config.components:
         track_path = config_file.parent / comp.target
         if track_path.is_file():
-            track_hash = hash_file(track_path)
+            track_hash = digest_file(track_path)
         else:
-            track_hash = hash_directory(track_path, comp.ignore)
+            track_hash = digest_directory(track_path, comp.ignore)
         comp.hash = track_hash
 
     write_local_config_file(config)
